@@ -1,5 +1,8 @@
 # Copyright (c) 2008-2014 Simplistix Ltd
 # See license.txt for license details.
+from datetime import date
+
+from functools import partial
 
 from collections import namedtuple
 from mock import Mock, call
@@ -1303,3 +1306,70 @@ b
 
     def test_dont_raise(self):
         self.assertEqual(compare('x', 'y', raises=False), "'x' != 'y'")
+
+    class OrmObj(object):
+        def __init__(self, a):
+            self.a = a
+        def __eq__(self, other):
+            return True
+        def __repr__(self):
+            return 'OrmObj: '+str(self.a)
+
+    def test_django_orm_is_horrible(self):
+
+        self.assertTrue(self.OrmObj(1) == self.OrmObj(2))
+
+        def query_set():
+            yield self.OrmObj(1)
+            yield self.OrmObj(2)
+
+        def compare_orm_obj(x, y, context):
+            if x.a != y.a:
+                return 'OrmObj: %s != %s' % (x.a, y.a)
+
+        self.checkRaises(
+            message=(
+                "sequence not as expected:\n\n"
+                "same:\n(OrmObj: 1,)\n\n"
+                "expected:\n(OrmObj: 3,)\n\n"
+                "actual:\n(OrmObj: 2,)\n\n"
+                "While comparing [1]: OrmObj: 3 != 2"
+            ),
+            expected=[self.OrmObj(1), self.OrmObj(3)],
+            actual=query_set(),
+            comparers={self.OrmObj: compare_orm_obj},
+            ignore_eq=True
+        )
+
+    def test_django_orm_is_horrible_part_2(self):
+
+        def compare_orm_obj(x, y, context):
+            return context.different(x.a, y.a, '.a')
+
+        t_compare = partial(compare,
+                            comparers={self.OrmObj: compare_orm_obj},
+                            ignore_eq=True)
+
+        t_compare(self.OrmObj(1), self.OrmObj(1))
+        t_compare(self.OrmObj('some longish string'),
+                  self.OrmObj('some longish string'))
+        t_compare(self.OrmObj(date(2016, 1, 1)),
+                  self.OrmObj(date(2016, 1, 1)))
+
+    def test_django_orm_is_horrible_part_3(self):
+        self.checkRaises(
+            message=(
+                "OrmObj: 1 (expected) != OrmObj: 1 (actual)"
+            ),
+            expected=self.OrmObj(1),
+            actual=self.OrmObj(1),
+            ignore_eq=True
+        )
+
+    def test_django_orm_is_horrible_part_4(self):
+        self.checkRaises(
+            message='[1] (expected) != 2 (actual)',
+            expected=[1],
+            actual=2,
+            ignore_eq=True
+        )
